@@ -20,7 +20,7 @@ SORT_DIR_VALUES = ('asc', 'desc')
 
 SHARE_SORT_KEY_VALUES = (
     'id', 'status', 'size', 'host', 'share_proto',
-    'export_location', 'availability_zone',
+    'availability_zone',
     'user_id', 'project_id',
     'created_at', 'updated_at',
     'display_name', 'name',
@@ -41,7 +41,7 @@ SNAPSHOT_SORT_KEY_VALUES = (
     'display_name',
 )
 
-CONSISTENCY_GROUP_SORT_KEY_VALUES = (
+SHARE_GROUP_SORT_KEY_VALUES = (
     'id',
     'name',
     'status',
@@ -49,10 +49,15 @@ CONSISTENCY_GROUP_SORT_KEY_VALUES = (
     'user_id',
     'project_id',
     'created_at',
-    'source_cgsnapshot_id',
+    'availability_zone',
+    'share_network',
+    'share_network_id',
+    'share_group_type',
+    'share_group_type_id',
+    'source_share_group_snapshot_id',
 )
 
-CG_SNAPSHOT_SORT_KEY_VALUES = (
+SHARE_GROUP_SNAPSHOT_SORT_KEY_VALUES = (
     'id',
     'name',
     'status',
@@ -60,21 +65,32 @@ CG_SNAPSHOT_SORT_KEY_VALUES = (
     'user_id',
     'project_id',
     'created_at',
+    'share_group_id',
 )
 
-CG_SNAPSHOT_MEMBERS_SORT_KEY_VALUES = (
-    'id',
-    'name',
-    'created_at',
-    'size',
-    'share_protocol',
-    'project_id',
-    'share_type_id',
-    'cgsnapshot_id',
-)
+TASK_STATE_MIGRATION_SUCCESS = 'migration_success'
+TASK_STATE_MIGRATION_ERROR = 'migration_error'
+TASK_STATE_MIGRATION_CANCELLED = 'migration_cancelled'
+TASK_STATE_MIGRATION_DRIVER_PHASE1_DONE = 'migration_driver_phase1_done'
+TASK_STATE_DATA_COPYING_COMPLETED = 'data_copying_completed'
 
 EXPERIMENTAL_HTTP_HEADER = 'X-OpenStack-Manila-API-Experimental'
 V1_SERVICE_TYPE = 'share'
 V2_SERVICE_TYPE = 'sharev2'
 
 SERVICE_TYPES = {'1': V1_SERVICE_TYPE, '2': V2_SERVICE_TYPE}
+
+EXTENSION_PLUGIN_NAMESPACE = 'manilaclient.common.apiclient.auth'
+MESSAGE_SORT_KEY_VALUES = (
+    'id', 'project_id', 'request_id', 'resource_type', 'action_id',
+    'detail_id', 'resource_id', 'message_level', 'expires_at',
+    'request_id', 'created_at'
+)
+
+STATUS_AVAILABLE = 'available'
+STATUS_ERROR = 'error'
+STATUS_ACTIVE = 'active'
+STATUS_MANAGE_ERROR = 'manage_error'
+STATUS_UNMANAGE_ERROR = 'unmanage_error'
+STATUS_DELETING = 'deleting'
+STATUS_CREATING = 'creating'
